Core Developers
===================
- Aniruddha Bhattacharjee (@anirudnits)
- Daniël van Noord (@DanielNoord) 
- Jon Dufresne (@jdufresne)
- Tamas Szabo (@sztamas)
- Thiago A. (@staticdev)
- Timothy Edmund Crosley (@timothycrosley)

Plugin Writers
===================
- *VIM* - Juan Pedro Fisanotti (@fisadev)
- *Emacs* - Friedrich Paetzke (@paetzke)
- *Sublime* - Thijs de Zoute (@thijsdezoete)

Notable Bug Reporters
===================
- Bengt Lüers (@Bengt)
- Chris Adams (@acdha)
- @OddBloke
- Martin Geisler (@mgeisleinr)
- Tim Heap (@timheap)
- Matěj Nikl (@MatejNikl)

Code Contributors
===================
- Aaron Gallagher (@habnabit)
- Thomas Grainger (@graingert)
- Thijs de Zoute (@thijsdezoete)
- Marc Abramowitz (@msabramo)
- Daniel Cowgill (@dcowgill)
- Francois Lebel (@flebel)
- Antoni Segura Puimedon (@celebdor)
- Pablo (@oubiga)
- Oskar Hahn (@ostcar)
- Wim Glenn (@wimglenn)
- Matt Caldwell (@mattcaldwell)
- Dwayne Bailey (@dwaynebailey)
- Ionel Cristian Mărieș (@ionelmc)
- Chris Adams (@acdha)
- GuoJing (@GuoJing)
- George Hickman (@ghickman)
- Dan Davison (@dandavison)
- Maciej Wolff (@maciejwo)
- Elliott Sales de Andrade (@qulogic)
- Kasper Jacobsen (@dinoshauer)
- Sebastian Pipping (@hartwork)
- Helen Sherwood-Taylor (@helenst)
- Mocker (@Zuckonit)
- Tim Graham (@timgraham)
- Adam (@NorthIsUp)
- Norman Jäckel (@normanjaeckel)
- Derrick Petzold (@dpetzold)
- Michael van Tellingen (@mvantellingen)
- Patrick Yevsukov (@patrickyevsukov)
- Christer van der Meeren (@cmeeren)
- Timon Wong/NHNCN (@timonwong)
- Jeremy Dunck (@jdunck)
- Benjamin ABEL (@benjaminabel)
- Dan Baragan (@danbaragan)
- Rob Cowie (@robcowie)
- Amit Shah (@Amwam)
- Patrick Gerken (@do3cc)
- @dein0s
- David Stensland (@terite)
- Ankur Dedania (@AbsoluteMSTR)
- Lee Packham (@leepa)
- Jesse Mullan (@jmullan)
- Kwok-kuen Cheung (@cheungpat)
- Johan Bloemberg (@aequitas)
- Dan Watson (@dcwatson)
- Éric Araujo (@merwok)
- Dan Palmer (@danpalmer)
- Andy Boot (@bootandy)
- @m7v8
- John Vandenberg (@jayvdb)
- Adam Chainz (@adamchainz)
- @Brightcells
- Jonas Trappenberg (@teeberg)
- Andrew Konstantaras (@akonsta)
- Jason Brackman (@jasonbrackman)
- Kathryn Lingel (@katlings)
- Andrew Gaul (@gaul)
- John Chadwick (@jchv)
- Jon Dufresne (@jdufresne)
- Brian F. Baron (@briabar)
- Madison Caldwell (@madirey)
- Matt Yule-Bennett (@mattbennett)
- Jaswanth Kumar (@jaswanth098)
- Dario Navin (@Zarathustra2)
- Danny Weinberg (@FuegoFro)
- Gram (@orsinium)
- Hugo van Kemenade (@hugovk)
- Géry Ogam (@maggyero)
- Cody Scott (@Siecje)
- Pedro Algarvio (@s0undt3ch)
- Chris St. Pierre (@stpierre)
- Sebastian Rittau (@srittau)
- João M.C. Teixeira (@joaomcteixeira)
- Honnix (@honnix)
- Anders Kaseorg (@andersk)
- @r-richmond
- Sebastian (@sebix)
- Kosei Kitahara (@Surgo)
- Seung Hyeon, Kim (@hyeonjames)
- Gerard Dalmau (@gdalmau)
- Robert Tasarz (@rtasarz)
- Ryo Miyajima (@sergeant-wizard)
- @mdagaro
- Maksim Kurnikov (@mkurnikov)
- Daniel Hahler (@blueyed)
- @ucodery
- Aarni Koskela (@akx)
- Alex Chan (@alexwlchan)
- Rick Thomas (@richardlthomas)
- Jeppe Fihl-Pearson (@Tenzer)
- Jonas Lundberg (@lundberg)
- Neil (@NeilGirdhar)
- @dmanikowski-reef
- Stephen Brown II (@StephenBrown2)
- Ankur Dedania (@AnkurDedania)
- Anthony Sottile (@asottile)
- Bendik Samseth (@bsamseth)
- Dan W Anderson (@anderson-dan-w)
- DeepSource Bot (@deepsourcebot)
- Mitar (@mitar)
- Omer Katz (@thedrow)
- Santiago Castro (@bryant1410)
- Sergey Fursov (@GeyseR)
- Thomas Robitaille (@astrofrog)
- Ville Skyttä (@scop)
- Hakan Çelik (@hakancelik96)
- Dylan Katz (@Plazmaz)
- Linus Lewandowski (@LEW21)
- Bastien Gérard (@bagerard)
- Brian Dombrowski (@bdombro)
- Ed Morley (@edmorley)
- Graeme Coupar (@obmarg)
- Jerome Leclanche (@jleclanche)
- Joshu Coats (@rhwlo)
- Mansour Behabadi (@oxplot)
- Sam Lai (@slai)
- Tamas Szabo (@sztamas)
- Yedidyah Bar David (@didib)
- Hidetoshi Hirokawa (@h-hirokawa)
- Aaron Chong (@acjh)
- Harai Akihiro (@harai)
- Andy Freeland (@rouge8)
- @ethifus
- Joachim Brandon LeBlanc (@demosdemon)
- Brian May (@brianmay)
- Bruno Oliveira (@nicoddemus)
- Bruno Renié (@brutasse)
- Bryce Guinta (@brycepg)
- David Chan (@dchanm)
- David Smith (@smithdc1)
- Irv Lustig (@Dr-Irv)
- Dylan Richardson (@dylrich)
- Emil Melnikov (@emilmelnikov)
- Eric Johnson (@metrizable)
- @ryabtsev
- Felix Yan (@felixonmars)
- Gil Forcada Codinachs (@gforcada)
- Ilya Konstantinov (@ikonst)
- Jace Browning (@jacebrowning)
- Jin Suk Park (@jinmel)
- Jürgen Gmach (@jugmac00)
- Maciej Gawinecki (@dzieciou)
- Minn Soe (@MinnSoe)
- Nikolaus Wittenstein (@adzenith)
- Norman J. Harman Jr. (@njharman)
- P R Gurunath (@gurunath-p)
- Patrick Hayes (@pfhayes)
- Pete Grayson (@jpgrayson)
- Philip Jenvey (@pjenvey)
- Rajiv Bakulesh Shah (@brainix)
- Reid D McKenzie (@arrdem)
- Robert DeRose (@RobertDeRose)
- Roey Darwish Dror (@r-darwish)
- Rudinei Goi Roecker (@rudineirk)
- Wagner (@wagner-certat)
- Nikita Sobolev (@sobolevn)
- Terence Honles (@terencehonles)
- The Gitter Badger (@gitter-badger)
- Tim Gates (@timgates42)
- Tim Staley (@timstaley)
- Vincent Hatakeyama (@vincent-hatakeyama)
- Yaron de Leeuw (@jarondl)
- @jwg4
- @nicolelodeon
- Łukasz Langa (@ambv)
- Grzegorz Pstrucha (@Gricha)
- Zac Hatfield-Dodds (@Zac-HD)
- Jiří Škorpil (@JiriSko)
- James Winegar (@jameswinegar)
- Abdullah Dursun (@adursun)
- Guillaume Lostis (@glostis)
- Krzysztof Jagiełło (@kjagiello)
- Nicholas Devenish (@ndevenish)
- Aniruddha Bhattacharjee (@anirudnits)
- Alexandre Yang (@AlexandreYang)
- Andrew Howe (@howeaj)
- Sang-Heon Jeon (@lntuition)
- Denis Veselov (@saippuakauppias)
- James Curtin (@jamescurtin)
- Marco Gorelli (@MarcoGorelli)
- Louis Sautier (@sbraz)
- Timur Kushukov (@timqsh)
- Bhupesh Varshney (@Bhupesh-V)
- Rohan Khanna (@rohankhanna)
- Vasilis Gerakaris (@vgerak)
- @tonci-bw
- @jaydesl
- Tamara (@infinityxxx)
- Akihiro Nitta (@akihironitta)
- Samuel Gaist (@sgaist)
- @dwanderson-intel
- Quentin Santos (@qsantos)
- @gofr
- Pavel Savchenko (@asfaltboy)
- @dongfangtianyu
- Christian Clauss (@cclauss)
- Jon Banafato (@jonafato)
- ruro (@RuRo)
- Léni (@legau)
- keno (Ken Okada) (@kenoss)
- Shota Terashita (@shotat)
- Luca Di sera (@diseraluca)
- Tonye Jack (@jackton1)
- Yusuke Hayashi (@yhay81)
- Arthur Rio (@arthurio)
- Bob (@bobwalker99)
- Martijn Pieters (@mjpieters)
- Asiel Díaz Benítez (@adbenitez)
- Almaz (@monosans)
- Mathieu Kniewallner (@mkniewallner)
- Christian Decker (@chrisdecker1201)
- Adam Parkin (@pzelnip)
- @MapleCCC
- @Parnassius
- @SaucyGames05
- Tim Heap (@mx-moth)

Documenters
===================
- Reinout van Rees (@reinout)
- Helen Sherwood-Taylor (@helenst)
- Elliott Sales de Andrade (@QuLogic)
- Brian Peiris (@brianpeiris)
- Tim Graham (@timgraham)
- Josh Soref (@jsoref)
- Teg Khanna (@tegkhanna)
- Sarah Beth Tracy (@sbtries)
- Aaron Brown (@aaronvbrown)
- Harutaka Kawamura (@harupy)
- Brad Solomon (@bsolomon1124)
- Martynas Mickevičius (@2m)
- Taneli Hukkinen (@hukkinj1)
- @r-richmond
- John Villalovos (@JohnVillalovos)
- Kosei Kitahara (@Surgo)
- Marat Sharafutdinov (@decaz)
- Abtin (@abtinmo)
- @scottwedge
- Hasan Ramezani (@hramezani)
- @hirosassa
- David Poznik (@dpoznik)
- Mike Frysinger (@vapier)
- @DanielFEvans
- Giuseppe Lumia (@glumia)
- John Brock (@JohnHBrock)
- Sergey Fedoseev (@sir-sigurd)

--------------------------------------------

A sincere thanks to everyone who has helped isort be the great utility it is today!
It would not be one-hundredth as useful and consistent as it is now without the help of your bug reports,
commits, and suggestions. You guys rock!

~Timothy Crosley
